# TrackGrab!

A minimal tool to download your favourite songs from Spotify!

## Licensing & Distribution Rights

This tool is created & developed under the guidelines of a FOSS license, more
specifically the MIT License. You can read the entire licensing details here
at - [LICENSE](./LICENSE).

On a further note, this project & its author isn't liable for any copyright
infringements. All copyright of the music you download using this tool is held
by the original artists of the product & its publishers.
